<?php
/*
*  @ Version 1.0.0 Beta 2008-03-02
*  @ Simply Links
*  @ Joomla! 1.5.X
*  @ Author: Anh Dai
*  @ Email: info@nekkarcity.de
*  @ License - GPL
*/

// no direct access
defined('_JEXEC') or die();

jimport('joomla.application.component.model');

class SimplylinksModelSimplylink extends JModel
{
	/**
	 * Simplylink id
	 *
	 * @var int
	 */
	var $_id = null;

	/**
	 * Simplylink data
	 *
	 * @var array
	 */
	var $_data = null;

	/**
	 * Constructor
	 *
	 * @since 1.5
	 */
	function __construct()
	{
		parent::__construct();

		$id = JRequest::getVar('id', 0, '', 'int');
		$this->setId((int)$id);
	}

	/**
	 * Method to set the simplylink identifier
	 *
	 * @access	public
	 * @param	int Simplylink identifier
	 */
	function setId($id)
	{
		// Set simplylink id and wipe data
		$this->_id		= $id;
		$this->_data	= null;
	}

	/**
	 * Method to get a simplylink
	 *
	 * @since 1.5
	 */
	function &getData()
	{
		// Load the simplylink data
		if ($this->_loadData())
		{
			// Initialize some variables
			$user = &JFactory::getUser();

			// Make sure the simplylink is published
			if (!$this->_data->published) {
				JError::raiseError(404, JText::_("Resource Not Found"));
				return false;
			}

			// Check to see if the category is published
			if (!$this->_data->cat_pub) {
				JError::raiseError( 404, JText::_("Resource Not Found") );
				return;
			}

			// Check whether category access level allows access
			if ($this->_data->cat_access > $user->get('aid', 0)) {
				JError::raiseError( 403, JText::_('ALERTNOTAUTH') );
				return;
			}
		}
		else  $this->_initData();

		return $this->_data;
	}

	/**
	 * Method to increment the hit counter for the simplylink
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function hit()
	{
		global $mainframe;

		if ($this->_id)
		{
			$simplylink = & $this->getTable();
			$simplylink->hit($this->_id);
			return true;
		}
		return false;
	}

	/**
	 * Method to store the simplylink
	 *
	 * @access	public
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function store($data)
	{
		$row =& $this->getTable();

		// Bind the form fields to the simply link table
		if (!$row->bind($data)) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// Create the timestamp for the date
		$row->date = gmdate('Y-m-d H:i:s');

		// if new item, order last in appropriate group
		if (!$row->id) {
			$where = 'catid = ' . (int) $row->catid ;
			$row->ordering = $row->getNextOrder( $where );
		}
		// Make sure the simply link table is valid
		if (!$row->check()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		// Store the simply link table to the database
		if (!$row->store()) {
			$this->setError($this->_db->getErrorMsg());
			return false;
		}

		return true;
	}

	/**
	 * Method to load content simplylink data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function _loadData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{
			$query = 'SELECT w.*, cc.title AS category,' .
					' cc.published AS cat_pub, cc.access AS cat_access'.
					' FROM #__simplylinks AS w' .
					' LEFT JOIN #__categories AS cc ON cc.id = w.catid' .
					' WHERE w.id = '. (int) $this->_id;
			$this->_db->setQuery($query);
			$this->_data = $this->_db->loadObject();
			return (boolean) $this->_data;
		}
		return true;
	}

	/**
	 * Method to initialise the simplylink data
	 *
	 * @access	private
	 * @return	boolean	True on success
	 * @since	1.5
	 */
	function _initData()
	{
		// Lets load the content if it doesn't already exist
		if (empty($this->_data))
		{
			$simplylink = new stdClass();
			$simplylink->id					= 0;
			$simplylink->catid				= 0;
			$simplylink->title				= null;
			$simplylink->url				= null;
			$simplylink->description			= null;
			$simplylink->date				= null;
			$simplylink->hits				= 0;
			$simplylink->published			= 0;
			$simplylink->checked_out			= 0;
			$simplylink->checked_out_time 	= 0;
			$simplylink->ordering			= 0;
			$simplylink->approved			= 0;
			$simplylink->category			= null;
			$this->_data					= $simplylink;
			return (boolean) $this->_data;
		}
		return true;
	}
}
?>
